@@ -1,7 +1,7 @@
 import abc
 import sys
 from collections import OrderedDict
-from typing import Any, Dict, Union
+from typing import Any, Dict, List, Optional, Union
 
 if sys.version_info[0] == 2:  # Python 2
 
@@ -68,6 +68,14 @@ class EnvMapper(ConfigConvert):
         # type: (Dict[str, str]) -> Dict[str, str]
         raise NotImplementedError()
 
+    def get_value(self, env_vars, possible_value, default=None):
+        # type: (Dict[str, str], List[str], str) -> Optional[str]
+        for value in possible_value:
+            res = env_vars.get(value)
+            if res:
+                return res
+        return default
+
 
 class OdooConfigABC(ConfigConvert, ABC):
     def __init__(self, main_instance=True):
