@@ -6,7 +6,7 @@ import pprint
 from collections import OrderedDict
 from typing import Dict, List, Optional
 
-from .api import ConfigConvert, Dictable, EnvMapper, OdooConfigABC
+from .api import ABC, ConfigConvert, Dictable, EnvMapper, OdooConfigABC
 from .config_section import (
     AddonsPathConfigSection,
     DatabaseOdooConfigSection,
@@ -39,7 +39,21 @@ def is_main_instance(env_vars):
     return env_vars.get("INSTANCE_NUMBER", 0) == 0
 
 
-class OdooConfig(OdooConfigABC, Dictable):
+class ToOdooArgs(ABC):
+    def to_odoo_args(self):
+        # type: () -> List[str]
+        pass
+
+
+class OdooConfigFileRef(ToOdooArgs):
+    def __init__(self, odoo_rc=None):
+        self.odoo_rc = odoo_rc
+
+    def to_odoo_args(self):
+        return ["--config=%s" % self.odoo_rc]
+
+
+class OdooConfig(OdooConfigABC, Dictable, ToOdooArgs):
     def __init__(self, env_vars, odoo_rc=None, main_instance=None):
         super(OdooConfig, self).__init__(main_instance is None and is_main_instance(env_vars))
         self._odoo_version = self.to_int(env_vars.get("ODOO_VERSION"))
